#include <CORBA.h>
#include "omc_communication.h"
#include <iostream>

using namespace std;

int main(int argc, char* argv[])
{
  CORBA::ORB_var orb = CORBA::ORB_init(argc,argv);  
  
  if (argc < 3) {
    cerr << "Usage: " << argv[0] << " <objid-uri> <command>" << endl;
    return 1;
  }

  try {
    CORBA::Object_var obj = orb->string_to_object(argv[1]);

    OmcCommunication_var omc = OmcCommunication::_narrow(obj);
    
    if (CORBA::is_nil(omc)) {
      cerr << "Unable to connect to server" << endl;
      return 1;
    }
    char* res = omc->sendExpression(argv[2]);
    cout << "res=" << res << endl;
    CORBA::string_free(res);
  }
  catch(CORBA::Exception e) {
    e._print(cerr);
    return 1;
  }

  return 0;
}

/* 

Compile using :

g++ corbacomm.cpp -o corbacomm  -Imico/include -Lmico/lib omc_communication.o -lmico



Start cygwin or win32 server using "omc +d=interactiveCorba"

Call cygwin server using:

halarsso@S04012 /cygdrive/m/OpenModelica/mosh/src
$ ./corbacomm file:///tmp/openmodelica.halarsso.objid "model test end test;"
res=Ok

halarsso@S04012 /cygdrive/m/OpenModelica/mosh/src
$ ./corbacomm file:///tmp/openmodelica.halarsso.objid "list()"
res="model test
end test;

"
Call win32 server using:

halarsso@S04012 /cygdrive/m/OpenModelica/mosh/src
$ ./corbacomm file:///cygdrive/c/Documents\ and\ Settings/halarsso/Local\ Settings/Temp/openmodelica.objid "cd()"
res="m:\OpenModelica\mosh\src"

*/
